#define BOOST_TEST_MODULE seller

#include "../src/core/seller.h"

#include <array>

#include <boost/test/included/unit_test.hpp>

BOOST_AUTO_TEST_CASE(create_uuid_nil)
{
    Seller seller{};
    BOOST_TEST(seller.getUuid().is_nil() == true);
}

BOOST_AUTO_TEST_CASE(create_uuid)
{
    Seller seller{};
    seller.createUuid();
    BOOST_TEST(seller.getUuid().is_nil() == false);
}

BOOST_AUTO_TEST_CASE(create_many)
{
    constexpr unsigned int QUANTITY{10000};
    std::array<Seller, QUANTITY> sellers;
    for (unsigned i = 0; i < sellers.size(); i++) {
        sellers[i] = Seller();
        sellers[i].createUuid();
    }
}

BOOST_AUTO_TEST_CASE(with_article) {
    Seller seller("Max", "Mustermann");
    auto article = std::make_shared<Article>();
    article->setDescription("Test article");
    seller.addArticle(article);
    BOOST_TEST(seller.getArticles(false).at(0)->getDescription() == "Test article");
    BOOST_TEST(seller.numArticlesSold() == 0);
}